@@ -61,7 +61,9 @@ class KnowrithmClient:
         from knowrithm_py.services.dashboard import AnalyticsService
         from knowrithm_py.services.database import DatabaseService
         from knowrithm_py.services.document import DocumentService
+        from knowrithm_py.services.settings import SettingsService
         from knowrithm_py.services.lead import LeadService
+        from knowrithm_py.services.website import WebsiteService
         
         self.auth = AuthService(self)
         self.api_keys = ApiKeyService(self)
@@ -71,9 +73,11 @@ class KnowrithmClient:
         self.leads = LeadService(self)
         self.documents = DocumentService(self)
         self.databases = DatabaseService(self)
+        self.websites = WebsiteService(self)
         self.conversations = ConversationService(self)
         self.messages = MessageService(self)
         self.analytics = AnalyticsService(self)
+        self.settings = SettingsService(self)
         self.addresses = AddressService(self)
         self.admin = AdminService(self)
     
